@@ -7,13 +7,13 @@ from flipt.clients import client
 
 
 def flag_enabled(flag_key: str, user=None) -> bool:
-    if hasattr(settings, 'FLAG_OVERRIDDEN'):
-        override_value = settings.FLAG_OVERRIDDEN.get(flag_key)
+    if hasattr(settings, 'FLIPT_FLAG_OVERRIDDEN'):
+        override_value = settings.FLIPT_FLAG_OVERRIDDEN.get(flag_key)
         if override_value is not None:
             return bool(override_value)
 
     if client is None:
-        return getattr(settings, 'FLAG_DEFAULT', True)
+        return getattr(settings, 'FLIPT_FLAG_DEFAULT', True)
 
     request = EvaluationRequest(
         flag_key=flag_key,
